Aerosol1D
=========

.. currentmodule:: aerosoltools.aerosol1d

.. autoclass:: Aerosol1D
   :noindex:

Properties
----------

.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   Aerosol1D.activities
   Aerosol1D.activity_periods
   Aerosol1D.data
   Aerosol1D.dtype
   Aerosol1D.extra_data
   Aerosol1D.instrument
   Aerosol1D.metadata
   Aerosol1D.original_data
   Aerosol1D.serial_number
   Aerosol1D.time
   Aerosol1D.total_concentration
   Aerosol1D.unit

Methods
-------

.. autosummary::
   :toctree: _autosummary
   :nosignatures:

   Aerosol1D.copy_self
   Aerosol1D.get_activity_data
   Aerosol1D.mark_activities
   Aerosol1D.plot_total_conc
   Aerosol1D.summarize
   Aerosol1D.timecrop
   Aerosol1D.timerebin
   Aerosol1D.timeshift
   Aerosol1D.timesmooth
